#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'Denis Cornehl'
__email__ = 'denis.cornehl@gmail.com'
__version__ = '0.1.6'


from closeio import CloseIO, CloseIOError  # noqa
